@@ -2,6 +2,7 @@ import mig_create_short_cut
 
 mig = mig_create_short_cut.open_conn()
 mig_rep= mig_create_short_cut.get_change_log()
+mig_search= mig_create_short_cut.searches()
 mig_short_cut= mig_create_short_cut.bld_short_cuts()
 cube_it= mig_create_short_cut.cubes()
 username = "Administrator"
@@ -48,7 +49,7 @@ change_query={"chg_log_from_date":chg_log_from_date
               ,"mtdi_id":None
               ,"cube_name":"TestCube"}
 
-conn=mig.standard_login(base_url=base_url,username=username,password=password,project_id="B19DEDCC11D4E0EFC000EB9495D0F44F")
+conn=mig.login(base_url=base_url,username=username,password=password,project_id="B19DEDCC11D4E0EFC000EB9495D0F44F")
 
 #pass over the parameters
 mig_rep.set_md_rep_params(conn=conn,change_query=change_query,change_log_report=change_log_report)
@@ -80,7 +81,7 @@ cube_it.up_load_to_cube(conn=conn,cube_upload_param=cube_upload_param)
 
 #
 obj_id_l=['335FFA9640B5F1C1E0C0F3A469E627A8;55','59D59D7741F61B68480572B9B7A05709;4'] #Dossier & metric "hire date"
-used_obj_dict_l=mig_rep.used_by_obj_l_rec(project_id=change_log_report["chg_log_rep_proj_id"]
+used_obj_dict_l=mig_search.used_by_obj_l_rec(conn=conn,project_id=change_log_report["chg_log_rep_proj_id"]
                           ,obj_id_l=obj_id_l)
 #export search result to cube
 search_df=mig_rep.bld_df_from_search_result(search_l=used_obj_dict_l)
