@@ -16,7 +16,7 @@ from typing import Optional
 
 class open_conn():
 
-    def standard_login(self,base_url,project_id=None,*args,**kwargs):
+    def login(self,base_url,project_id=None,*args,**kwargs):
         return get_conn(self,base_url=base_url, project_id=project_id,*args,**kwargs)
 
 class prepare_mig_obj():
@@ -175,12 +175,6 @@ class get_change_log:
 
         return self.str._rem_last_char(where_str,1)
 
-    def used_by_obj_l_rec(self,project_id,obj_id_l):
-        return list(self.glob.used_by_obj_rec_l(conn=self.conn,
-                                                project_id=self.chg_log_rep_proj_id,
-                                                obj_l=obj_id_l)
-                    )
-
     def get_obj_l_from_search_l(self,search_l):
         obj_l=[]
         for o in search_l:
@@ -282,4 +276,15 @@ class get_change_log:
 
         if prompt_ans:
             prompt_ans = f'{{"prompts":[{prompt_ans}]}}'
-        return prompt_ans
\ No newline at end of file
+        return prompt_ans
+
+class searches:
+
+    def __init__(self):
+        self.glob = mstr_global()
+
+    def used_by_obj_l_rec(self,conn,project_id,obj_id_l):
+        return list(self.glob.used_by_obj_rec_l(conn=conn,
+                                                project_id=project_id,
+                                                obj_l=obj_id_l)
+                    )
\ No newline at end of file
